==> haskell-basement-0.0.7-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-basement.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: basement
version: 0.0.7
id: basement-0.0.7-IRcTCDmYoctGxt4FUYqdQc
key: basement-0.0.7-IRcTCDmYoctGxt4FUYqdQc
license: BSD3
copyright: Vincent Hanquez
maintainer: vincent@snarc.org
homepage: https://github.com/haskell-foundation/foundation
synopsis: Foundation scrap box of array & string
description:
    Foundation most basic primitives without any dependencies
category: Web
exposed: True
indefinite: False
exposed-modules:
    Basement.Alg.XorShift Basement.Base16 Basement.Bindings.Memory
    Basement.Bits Basement.Block Basement.Block.Builder
    Basement.Block.Mutable Basement.BlockN Basement.Bounded
    Basement.BoxedArray Basement.Cast Basement.Compat.AMP
    Basement.Compat.Base Basement.Compat.Bifunctor
    Basement.Compat.C.Types Basement.Compat.CallStack
    Basement.Compat.ExtList Basement.Compat.Identity
    Basement.Compat.IsList Basement.Compat.MonadTrans
    Basement.Compat.Natural Basement.Compat.NumLiteral
    Basement.Compat.PrimTypes Basement.Compat.Primitive
    Basement.Compat.Semigroup Basement.Compat.Typeable
    Basement.Endianness Basement.Environment Basement.Exception
    Basement.FinalPtr Basement.Floating Basement.From Basement.Imports
    Basement.IntegralConv Basement.Monad Basement.MutableBuilder
    Basement.Nat Basement.NonEmpty Basement.NormalForm
    Basement.Numerical.Additive Basement.Numerical.Multiplicative
    Basement.Numerical.Number Basement.Numerical.Subtractive
    Basement.PrimType Basement.Sized.Block Basement.Sized.List
    Basement.Sized.UVect Basement.Sized.Vect Basement.String
    Basement.String.Builder Basement.Terminal Basement.Terminal.ANSI
    Basement.These Basement.Types.AsciiString Basement.Types.Char7
    Basement.Types.OffsetSize Basement.Types.Ptr Basement.Types.Word128
    Basement.Types.Word256 Basement.UArray Basement.UArray.Mutable
hidden-modules: Basement.Error Basement.Show Basement.Runtime
                Basement.Alg.Class Basement.Alg.Mutable Basement.Alg.PrimArray
                Basement.Alg.UTF8 Basement.Alg.String Basement.Numerical.Conversion
                Basement.Block.Base Basement.UTF8.Base Basement.UTF8.Helper
                Basement.UTF8.Table Basement.UTF8.Types Basement.UArray.Base
                Basement.String.CaseMapping Basement.String.Encoding.Encoding
                Basement.String.Encoding.UTF16 Basement.String.Encoding.UTF32
                Basement.String.Encoding.ASCII7 Basement.String.Encoding.ISO_8859_1
                Basement.Terminal.Size
abi: fbee28466a7ad64c7b9a8e7e271c596e
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/basement-0.0.7
library-dirs: /usr/lib/ghc-8.2.2/site-local/basement-0.0.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/basement-0.0.7
hs-libraries: HSbasement-0.0.7-IRcTCDmYoctGxt4FUYqdQc
depends:
    base-4.10.1.0 ghc-prim-0.5.1.1
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             ghc-prim-0.5.1.1=84323a6edd008b04bf217464a4ccaf16
haddock-interfaces: /usr/share/doc/haskell-basement/html/basement.haddock
haddock-html: /usr/share/doc/haskell-basement/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-basement-0.0.7-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-basement.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: basement
version: 0.0.7
id: basement-0.0.7-2rr6CUCXDXO23STP232Skz
key: basement-0.0.7-2rr6CUCXDXO23STP232Skz
license: BSD-3-Clause
copyright: Vincent Hanquez
maintainer: vincent@snarc.org
homepage: https://github.com/haskell-foundation/foundation
synopsis: Foundation scrap box of array & string
description:
    Foundation most basic primitives without any dependencies
category: Web
abi: d615c78590e05db3cd1b90674918dce0
exposed: True
exposed-modules:
    Basement.Alg.XorShift Basement.Base16 Basement.Bindings.Memory
    Basement.Bits Basement.Block Basement.Block.Builder
    Basement.Block.Mutable Basement.BlockN Basement.Bounded
    Basement.BoxedArray Basement.Cast Basement.Compat.AMP
    Basement.Compat.Base Basement.Compat.Bifunctor
    Basement.Compat.C.Types Basement.Compat.CallStack
    Basement.Compat.ExtList Basement.Compat.Identity
    Basement.Compat.IsList Basement.Compat.MonadTrans
    Basement.Compat.Natural Basement.Compat.NumLiteral
    Basement.Compat.PrimTypes Basement.Compat.Primitive
    Basement.Compat.Semigroup Basement.Compat.Typeable
    Basement.Endianness Basement.Environment Basement.Exception
    Basement.FinalPtr Basement.Floating Basement.From Basement.Imports
    Basement.IntegralConv Basement.Monad Basement.MutableBuilder
    Basement.Nat Basement.NonEmpty Basement.NormalForm
    Basement.Numerical.Additive Basement.Numerical.Multiplicative
    Basement.Numerical.Number Basement.Numerical.Subtractive
    Basement.PrimType Basement.Sized.Block Basement.Sized.List
    Basement.Sized.UVect Basement.Sized.Vect Basement.String
    Basement.String.Builder Basement.Terminal Basement.Terminal.ANSI
    Basement.These Basement.Types.AsciiString Basement.Types.Char7
    Basement.Types.OffsetSize Basement.Types.Ptr Basement.Types.Word128
    Basement.Types.Word256 Basement.UArray Basement.UArray.Mutable
hidden-modules: Basement.Error Basement.Show Basement.Runtime
                Basement.Alg.Class Basement.Alg.Mutable Basement.Alg.PrimArray
                Basement.Alg.UTF8 Basement.Alg.String Basement.Numerical.Conversion
                Basement.Block.Base Basement.UTF8.Base Basement.UTF8.Helper
                Basement.UTF8.Table Basement.UTF8.Types Basement.UArray.Base
                Basement.String.CaseMapping Basement.String.Encoding.Encoding
                Basement.String.Encoding.UTF16 Basement.String.Encoding.UTF32
                Basement.String.Encoding.ASCII7 Basement.String.Encoding.ISO_8859_1
                Basement.Terminal.Size
import-dirs: /usr/lib/ghc-8.4.3/site-local/basement-0.0.7
library-dirs: /usr/lib/ghc-8.4.3/site-local/basement-0.0.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/basement-0.0.7
hs-libraries: HSbasement-0.0.7-2rr6CUCXDXO23STP232Skz
depends:
    base-4.11.1.0 ghc-prim-0.5.2.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             ghc-prim-0.5.2.0=387aa7e78e4e6c49e51798e4d6763c3f
haddock-interfaces: /usr/share/doc/haskell-basement/html/basement.haddock
haddock-html: /usr/share/doc/haskell-basement/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
